==> dynamodb-keyspace-0.0.6.tgz: package/dist-es/command/BatchWrite.js <==
import { BatchWriteCommand } from '@aws-sdk/lib-dynamodb';
import { DkCommand } from './Command';
import { lowerCaseKeys, upperCaseKeys } from '../util/keyCapitalize';
import { applyDefaults } from '../util/defaults';
import { executeMiddlewares, executeMiddleware } from '../Middleware';
const BATCH_WRITE_COMMAND_INPUT_DATA_TYPE = 'BatchWriteCommandInput';
const BATCH_WRITE_COMMAND_INPUT_HOOK = [
    'CommandInput',
    'WriteCommandInput',
    BATCH_WRITE_COMMAND_INPUT_DATA_TYPE
];
const BATCH_WRITE_COMMAND_OUTPUT_DATA_TYPE = 'BatchWriteCommandOutput';
const BATCH_WRITE_COMMAND_OUTPUT_HOOK = [
    'CommandOutput',
    'WriteCommandOutput',
    BATCH_WRITE_COMMAND_OUTPUT_DATA_TYPE
];
export class DkBatchWriteCommand extends DkCommand {
    constructor(input) {
        super(input);
        this.inputMiddlewareConfig = { dataType: BATCH_WRITE_COMMAND_INPUT_DATA_TYPE, hooks: BATCH_WRITE_COMMAND_INPUT_HOOK };
        this.outputMiddlewareConfig = { dataType: BATCH_WRITE_COMMAND_OUTPUT_DATA_TYPE, hooks: BATCH_WRITE_COMMAND_OUTPUT_HOOK };
        this.handleInput = async ({ defaults, middleware }) => {
            const postDefaultsInput = applyDefaults(this.input, defaults, [
                'returnConsumedCapacity',
                'returnItemCollectionMetrics'
            ]);
            const { data: postMiddlewareInput } = await executeMiddlewares([...this.inputMiddlewareConfig.hooks], {
                dataType: this.inputMiddlewareConfig.dataType,
                data: postDefaultsInput
            }, middleware);
            const { requests, ...rest } = postMiddlewareInput;
            const formattedInput = {
                requestItems: Object.fromEntries(Object.entries(requests).map(([tableName, requests]) => {
                    const formattedRequests = requests.map(request => {
                        if ('put' in request) {
                            return {
                                PutRequest: {
                                    Item: request.put
                                }
                            };
                        }
                        return {
                            DeleteRequest: {
                                Key: request.delete
                            }
                        };
                    });
                    return [tableName, formattedRequests];
                })),
                ...rest
            };
            const upperCaseInput = upperCaseKeys(formattedInput);
            return upperCaseInput;
        };
        this.handleOutput = async (output, { middleware }) => {
            const lowerCaseOutput = lowerCaseKeys(output);
            const { unprocessedItems, ...rest } = lowerCaseOutput;
            const formattedUnprocessedRequests = Object.fromEntries(Object.entries(unprocessedItems || {}).map(([tableName, requests]) => {
                const formattedRequests = requests.map(request => {
                    if (request.PutRequest) {
                        const item = request.PutRequest.Item;
                        return {
                            put: item
                        };
                    }
                    const key = request.DeleteRequest?.Key;
                    return {
                        delete: key
                    };
                });
                return [tableName, formattedRequests];
            }));
            const formattedOutput = {
                ...rest,
                unprocessedRequests: formattedUnprocessedRequests
            };
            const { data: postMiddlewareOutput } = await executeMiddlewares([...this.outputMiddlewareConfig.hooks], {
                dataType: this.outputMiddlewareConfig.dataType,
                data: formattedOutput
            }, middleware);
            if (postMiddlewareOutput.consumedCapacity) {
                for (const consumedCapacity of postMiddlewareOutput.consumedCapacity) {
                    await executeMiddleware('ConsumedCapacity', { dataType: 'ConsumedCapacity', data: consumedCapacity }, middleware);
                }
            }
            if (postMiddlewareOutput.itemCollectionMetrics) {
                await executeMiddleware('ItemCollectionMetrics', { dataType: 'ItemCollectionMetrics', data: postMiddlewareOutput.itemCollectionMetrics }, middleware);
            }
            return postMiddlewareOutput;
        };
        this.send = async (clientConfig) => {
            const input = await this.handleInput(clientConfig);
            const output = await clientConfig.client.send(new BatchWriteCommand(input));
            return this.handleOutput(output, clientConfig);
        };
    }
}

==> dynamodb-keyspace-0.0.7.tgz: package/dist-es/command/BatchWrite.js <==
import { BatchWriteCommand } from '@aws-sdk/lib-dynamodb';
import { DkCommand } from './Command';
import { uncapitalizeKeys, capitalizeKeys } from 'object-key-casing';
import { applyDefaults } from '../util/defaults';
import { executeMiddlewares, executeMiddleware } from '../Middleware';
const BATCH_WRITE_COMMAND_INPUT_DATA_TYPE = 'BatchWriteCommandInput';
const BATCH_WRITE_COMMAND_INPUT_HOOK = [
    'CommandInput',
    'WriteCommandInput',
    BATCH_WRITE_COMMAND_INPUT_DATA_TYPE
];
const BATCH_WRITE_COMMAND_OUTPUT_DATA_TYPE = 'BatchWriteCommandOutput';
const BATCH_WRITE_COMMAND_OUTPUT_HOOK = [
    'CommandOutput',
    'WriteCommandOutput',
    BATCH_WRITE_COMMAND_OUTPUT_DATA_TYPE
];
export class DkBatchWriteCommand extends DkCommand {
    constructor(input) {
        super(input);
        this.inputMiddlewareConfig = { dataType: BATCH_WRITE_COMMAND_INPUT_DATA_TYPE, hooks: BATCH_WRITE_COMMAND_INPUT_HOOK };
        this.outputMiddlewareConfig = { dataType: BATCH_WRITE_COMMAND_OUTPUT_DATA_TYPE, hooks: BATCH_WRITE_COMMAND_OUTPUT_HOOK };
        this.handleInput = async ({ defaults, middleware }) => {
            const postDefaultsInput = applyDefaults(this.input, defaults, [
                'returnConsumedCapacity',
                'returnItemCollectionMetrics'
            ]);
            const { data: postMiddlewareInput } = await executeMiddlewares([...this.inputMiddlewareConfig.hooks], {
                dataType: this.inputMiddlewareConfig.dataType,
                data: postDefaultsInput
            }, middleware);
            const { requests, ...rest } = postMiddlewareInput;
            const formattedInput = {
                requestItems: Object.fromEntries(Object.entries(requests).map(([tableName, requests]) => {
                    const formattedRequests = requests.map(request => {
                        if ('put' in request) {
                            return {
                                PutRequest: {
                                    Item: request.put
                                }
                            };
                        }
                        return {
                            DeleteRequest: {
                                Key: request.delete
                            }
                        };
                    });
                    return [tableName, formattedRequests];
                })),
                ...rest
            };
            const upperCaseInput = capitalizeKeys(formattedInput);
            return upperCaseInput;
        };
        this.handleOutput = async (output, { middleware }) => {
            const lowerCaseOutput = uncapitalizeKeys(output);
            const { unprocessedItems, ...rest } = lowerCaseOutput;
            const formattedUnprocessedRequests = Object.fromEntries(Object.entries(unprocessedItems || {}).map(([tableName, requests]) => {
                const formattedRequests = requests.map(request => {
                    if (request.PutRequest) {
                        const item = request.PutRequest.Item;
                        return {
                            put: item
                        };
                    }
                    const key = request.DeleteRequest?.Key;
                    return {
                        delete: key
                    };
                });
                return [tableName, formattedRequests];
            }));
            const formattedOutput = {
                ...rest,
                unprocessedRequests: formattedUnprocessedRequests
            };
            const { data: postMiddlewareOutput } = await executeMiddlewares([...this.outputMiddlewareConfig.hooks], {
                dataType: this.outputMiddlewareConfig.dataType,
                data: formattedOutput
            }, middleware);
            if (postMiddlewareOutput.consumedCapacity) {
                for (const consumedCapacity of postMiddlewareOutput.consumedCapacity) {
                    await executeMiddleware('ConsumedCapacity', { dataType: 'ConsumedCapacity', data: consumedCapacity }, middleware);
                }
            }
            if (postMiddlewareOutput.itemCollectionMetrics) {
                await executeMiddleware('ItemCollectionMetrics', { dataType: 'ItemCollectionMetrics', data: postMiddlewareOutput.itemCollectionMetrics }, middleware);
            }
            return postMiddlewareOutput;
        };
        this.send = async (clientConfig) => {
            const input = await this.handleInput(clientConfig);
            const output = await clientConfig.client.send(new BatchWriteCommand(input));
            return this.handleOutput(output, clientConfig);
        };
    }
}
